@@ -14,6 +14,7 @@ from pathlib import Path
 from bs4 import BeautifulSoup
 import fosslight_util.constant as constant
 from fosslight_util.compare_yaml import compare_yaml
+from fosslight_util.convert_excel_to_yaml import convert_excel_to_yaml
 
 logger = logging.getLogger(constant.LOGGER_NAME)
 ADD = "add"
@@ -21,14 +22,19 @@ DELETE = "delete"
 CHANGE = "change"
 COMP_STATUS = [ADD, DELETE, CHANGE]
 
+JSON_EXT = '.json'
+YAML_EXT = '.yaml'
+HTML_EXT = '.html'
+XLSX_EXT = '.xlsx'
+
 
 def write_result_json_yaml(output_file, compared_result, file_ext):
     ret = True
     try:
         with open(output_file, 'w') as f:
-            if file_ext == '.json':
+            if file_ext == JSON_EXT:
                 json.dump(compared_result, f, indent=4, sort_keys=True)
-            elif file_ext == '.yaml':
+            elif file_ext == YAML_EXT:
                 yaml.dump(compared_result, f, sort_keys=True)
     except Exception:
         ret = False
@@ -65,7 +71,7 @@ def parse_result_for_table(oi, status):
 
 def get_sample_html():
     RESOURCES_DIR = 'resources'
-    SAMPLE_HTML = 'bom_compare.html'
+    SAMPLE_HTML = f'bom_compare{HTML_EXT}'
     html_file = os.path.join(RESOURCES_DIR, SAMPLE_HTML)
     html_f = ''
 
@@ -83,14 +89,14 @@ def get_sample_html():
     return html_f
 
 
-def write_result_html(output_file, compared_result, before_yaml, after_yaml):
+def write_result_html(output_file, compared_result, before_f, after_f):
     ret = True
     html_f = get_sample_html()
     if html_f != '':
         try:
             f = BeautifulSoup(html_f.read(), 'html.parser')
-            f.find("li", {"class": "before_f"}).append(before_yaml)
-            f.find("li", {"class": "after_f"}).append(after_yaml)
+            f.find("li", {"class": "before_f"}).append(before_f)
+            f.find("li", {"class": "after_f"}).append(after_f)
 
             table_html = f.find("table", {"id": "comp_result"})
 
@@ -149,7 +155,7 @@ def write_result_xlsx(output_file, compared_result):
         output_dir = os.path.dirname(output_file)
         Path(output_dir).mkdir(parents=True, exist_ok=True)
 
-        workbook = xlsxwriter.Workbook(os.path.basename(output_file))
+        workbook = xlsxwriter.Workbook(output_file)
         worksheet = workbook.add_worksheet('BOM_compare')
         bold = workbook.add_format({'bold': True})
         worksheet.write_row(0, 0, HEADER, bold)
@@ -170,22 +176,22 @@ def write_result_xlsx(output_file, compared_result):
     return ret
 
 
-def write_compared_result(output_file, compared_result, file_ext, before_yaml='', after_yaml=''):
+def write_compared_result(output_file, compared_result, file_ext, before_f='', after_f=''):
     success = False
-    if file_ext == "" or file_ext == ".xlsx":
+    if file_ext == "" or file_ext == XLSX_EXT:
         success = write_result_xlsx(output_file, compared_result)
-    elif file_ext == ".html":
-        output_xlsx_file = os.path.splitext(output_file)[0] + ".xlsx"
+    elif file_ext == HTML_EXT:
+        output_xlsx_file = f'{os.path.splitext(output_file)[0]}{XLSX_EXT}'
         success_xlsx = write_result_xlsx(output_xlsx_file, compared_result)
-        success = write_result_html(output_file, compared_result, before_yaml, after_yaml)
+        success = write_result_html(output_file, compared_result, before_f, after_f)
         if not success_xlsx:
             logger.error("Fail to write comparison excel file.")
         else:
             logger.info(f"In html format, {output_xlsx_file} is generated by default.")
             output_file = f"{output_xlsx_file}, {output_file}"
-    elif file_ext == ".json":
+    elif file_ext == JSON_EXT:
         success = write_result_json_yaml(output_file, compared_result, file_ext)
-    elif file_ext == ".yaml":
+    elif file_ext == YAML_EXT:
         success = write_result_json_yaml(output_file, compared_result, file_ext)
     else:
         logger.info("Not supported file extension")
@@ -195,17 +201,18 @@ def write_compared_result(output_file, compared_result, file_ext, before_yaml=''
 
 def get_comparison_result_filename(output_path, output_file, output_extension, _start_time):
     result_file = ""
+    compare_prefix = f"fosslight_compare_{_start_time}"
     if output_file != "":
         result_file = f"{output_file}{output_extension}"
     else:
-        if output_extension == '.xlsx' or output_extension == "":
-            result_file = f"FOSSLight_Compare_{_start_time}.xlsx"
-        elif output_extension == '.html':
-            result_file = f"FOSSLight_Compare_{_start_time}.html"
-        elif output_extension == '.yaml':
-            result_file = f"FOSSLight_Compare_{_start_time}.yaml"
-        elif output_extension == '.json':
-            result_file = f"FOSSLight_Compare_{_start_time}.json"
+        if output_extension == XLSX_EXT or output_extension == "":
+            result_file = f"{compare_prefix}{XLSX_EXT}"
+        elif output_extension == HTML_EXT:
+            result_file = f"{compare_prefix}{HTML_EXT}"
+        elif output_extension == YAML_EXT:
+            result_file = f"{compare_prefix}{YAML_EXT}"
+        elif output_extension == JSON_EXT:
+            result_file = f"{compare_prefix}{JSON_EXT}"
         else:
             logger.error("Not supported file extension")
 
@@ -224,13 +231,33 @@ def count_compared_result(compared_result):
     logger.info(f"Comparison result: {count_str}")
 
 
-def run_compare(before_yaml, after_yaml, output_path, output_file, file_ext, _start_time):
+def run_compare(before_f, after_f, output_path, output_file, file_ext, _start_time, _output_dir):
     ret = False
+    before_yaml = ''
+    after_yaml = ''
     logger.info("Start compare mode")
-    logger.info(f"before file: {before_yaml}")
-    logger.info(f"after file: {after_yaml}")
+    logger.info(f"before file: {before_f}")
+    logger.info(f"after file: {after_f}")
+
+    before_ext = f'.{os.path.basename(before_f).split(".")[-1]}'
+    after_ext = f'.{os.path.basename(after_f).split(".")[-1]}'
+    if before_ext != after_ext:
+        logger.error("Please enter the two FOSSLight report with the same file extension.")
+        return False
+    if before_ext not in [YAML_EXT, XLSX_EXT]:
+        logger.error(f"Compare mode only supports 'yaml' or 'xlsx' extension. (input extension:{before_ext})")
+        return False
+    else:
+        tmp_b_yaml = f'{os.path.basename(before_f).rstrip(XLSX_EXT)}{YAML_EXT}'
+        before_yaml = before_f if before_ext == YAML_EXT else os.path.join(_output_dir, tmp_b_yaml)
+        tmp_a_yaml = f'{os.path.basename(after_f).rstrip(XLSX_EXT)}{YAML_EXT}'
+        after_yaml = after_f if after_ext == YAML_EXT else os.path.join(_output_dir, tmp_a_yaml)
 
     result_file = get_comparison_result_filename(output_path, output_file, file_ext, _start_time)
+
+    if before_ext == XLSX_EXT:
+        convert_excel_to_yaml(before_f, before_yaml)
+        convert_excel_to_yaml(after_f, after_yaml)
     compared_result = compare_yaml(before_yaml, after_yaml)
     if compared_result != '':
         count_compared_result(compared_result)
